EDAM package
============

Module contents
---------------

.. automodule:: edam
   :members:

.. automodule:: edam.reader.models
   :members:

.. automodule:: edam.reader.TemplateReader
   :members:

.. automodule:: edam.reader.utilities
   :members:

